@@ -12,7 +12,7 @@ names(criteriaMinMax) <- c("g1","g2","g3","g4","g5","g6")
 
 # plotRadarPerformanceTable(performanceTable, criteriaMinMax, overlay=TRUE)
 
-plotRadarPerformanceTable(performanceTable, criteriaMinMax, alternativesIDs <- c("x1","x2","x3","x4"), criteriaIDs<-c("g1","g3","g4","g5","g6"), overlay=FALSE)
+plotRadarPerformanceTable(performanceTable, criteriaMinMax, alternativesIDs <- c("x1","x2","x3","x4"), criteriaIDs<-c("g1","g3","g4","g5","g6"), overlay=FALSE, bw=FALSE)
 
 # plotRadarPerformanceTable(performanceTable, criteriaMinMax, alternativesIDs <- c("x1","x2"), criteriaIDs<-c("g1","g3","g4","g5","g6"), overlay=FALSE)
 
